@@ -29,7 +29,6 @@ class RedisCache(BaseCache):
         Connect to Redis, and set up cache backend.
         """
         self._init(server, params)
-        super(RedisCache, self).__init__(params)
 
     def _connect(self):
         unix_socket_path = None
@@ -216,7 +215,8 @@ class RedisCache(BaseCache):
 
         pattern = self.make_key(pattern, version=version)
         keys = client.keys(pattern)
-        client.delete(*keys)
+        if keys:
+            client.delete(*keys)
 
     def delete_many(self, keys, version=None):
         """
@@ -287,7 +287,6 @@ class RedisCache(BaseCache):
             client = self._client
 
         key = self.make_key(key, version=version)
-        exists = client.exists(key)
 
         if not client.exists(key):
             raise ValueError("Key '%s' not found" % key)
@@ -374,6 +373,11 @@ class ShardedRedisCache(RedisCache):
         name = self.ring.get_node(key)
         return name
 
+    def close(self):
+        for cli in self.connections.values():
+            for c in cli.connection_pool._available_connections:
+                c.disconnect()
+
     def get_server(self,key):
         name = self.get_server_name(key)
         return self.connections[name]
@@ -422,7 +426,6 @@ class ShardedRedisCache(RedisCache):
         return super(ShardedRedisCache, self).set(key=key, value=value, timeout=timeout,
                                                         version=version, client=client)
 
-
     def set_many(self, data, timeout=None, version=None):
         """
         Set a bunch of values in the cache at once from a dict of key/value
@@ -465,7 +468,6 @@ class ShardedRedisCache(RedisCache):
         return super(ShardedRedisCache, self).incr(key=key, delta=delta,
                                         version=version, client=client)
 
-
     def decr(self, key, delta=1, version=None, client=None):
         if client is None:
             key = self.make_key(key, version=version)
@@ -473,3 +475,10 @@ class ShardedRedisCache(RedisCache):
 
         return super(ShardedRedisCache, self).decr(key=key, delta=delta,
                                         version=version, client=client)
+
+
+    def delete_pattern(self, pattern, version=None, client=None):
+        """
+        Remove all keys matching pattern.
+        """
+        raise NotImplementedError
